@@ -1,5 +1,5 @@
 Rt.fun <-
-function(ord.delta,ord.wt,s0){
+function(ord.delta,s0,ord.wt){
     Rt = cumsum(ord.wt*ord.delta/s0)
     return(Rt)
 }
